gconf r2503 - in trunk: . gconf
- From: kmaraas svn gnome org
- To: svn-commits-list gnome org
- Subject: gconf r2503 - in trunk: . gconf
- Date: Tue, 8 Jan 2008 14:31:11 +0000 (GMT)
Author: kmaraas
Date: Tue Jan 8 14:31:11 2008
New Revision: 2503
URL: http://svn.gnome.org/viewvc/gconf?rev=2503&view=rev
Log:
2008-01-08 Kjartan Maraas <kmaraas gnome org>
* gconf/gconf-database.c: (gconf_database_sync):
* gconf/gconf-internals.c:
* gconf/gconf-listeners.c:
* gconf/gconf-sources.c: (gconf_sources_new_from_addresses):
* gconf/gconf.c: (gconf_engine_unref), (gconf_shutdown_daemon):
* gconf/gconfd.c: (gconf_server_load_sources),
(gconfd_check_in_shutdown), (parse_listener_entry):
* gconf/gconftool.c: (main), (do_spawn_daemon), (do_sync):
More string reviews from Christian Rose and Adam Weinberger.
Closes bug #318600.
Modified:
trunk/ChangeLog
trunk/gconf/gconf-database.c
trunk/gconf/gconf-internals.c
trunk/gconf/gconf-listeners.c
trunk/gconf/gconf-sources.c
trunk/gconf/gconf.c
trunk/gconf/gconfd.c
trunk/gconf/gconftool.c
Modified: trunk/gconf/gconf-database.c
==============================================================================
--- trunk/gconf/gconf-database.c (original)
+++ trunk/gconf/gconf-database.c Tue Jan 8 14:31:11 2008
@@ -1684,7 +1684,7 @@
db->last_access = time(NULL);
- gconf_log(GCL_DEBUG, "Received suggestion to sync all config data");
+ gconf_log(GCL_DEBUG, "Received suggestion to sync all configuration data");
gconf_database_sync_nowish(db);
}
Modified: trunk/gconf/gconf-internals.c
==============================================================================
--- trunk/gconf/gconf-internals.c (original)
+++ trunk/gconf/gconf-internals.c Tue Jan 8 14:31:11 2008
@@ -658,7 +658,7 @@
}
/*
- * Config files (yikes! we can't store our config in GConf!)
+ * Configuration files (yikes! we can't store our configuration in GConf!)
*/
static gchar*
Modified: trunk/gconf/gconf-listeners.c
==============================================================================
--- trunk/gconf/gconf-listeners.c (original)
+++ trunk/gconf/gconf-listeners.c Tue Jan 8 14:31:11 2008
@@ -57,7 +57,7 @@
typedef struct _LTable LTable;
struct _LTable {
- GNode* tree; /* Represents the config "filesystem" namespace.
+ GNode* tree; /* Represents the configuration "filesystem" namespace.
* Kept sorted.
*/
GPtrArray* listeners; /* Listeners are also kept in a flat array here, indexed by connection number */
Modified: trunk/gconf/gconf-sources.c
==============================================================================
--- trunk/gconf/gconf-sources.c (original)
+++ trunk/gconf/gconf-sources.c Tue Jan 8 14:31:11 2008
@@ -421,7 +421,7 @@
{
some_writable = TRUE;
gconf_log (GCL_INFO,
- _("Resolved address \"%s\" to a partially writable config source at position %d"),
+ _("Resolved address \"%s\" to a partially writable configuration source at position %d"),
source->address, i);
}
Modified: trunk/gconf/gconf.c
==============================================================================
--- trunk/gconf/gconfd.c (original)
+++ trunk/gconf/gconfd.c Tue Jan 8 14:31:11 2008
@@ -351,7 +351,7 @@
/* Try using the default address xml:readwrite:$(HOME)/.gconf */
addresses = g_slist_append(addresses, g_strconcat("xml:readwrite:", home, "/.gconf", NULL));
- gconf_log(GCL_DEBUG, _("No configuration files found, trying to use the default config source `%s'"), (char *)addresses->data);
+ gconf_log(GCL_DEBUG, _("No configuration files found. Trying to use the default configuration source `%s'"), (char *)addresses->data);
}
if (addresses == NULL)
@@ -359,7 +359,7 @@
/* We want to stay alive but do nothing, because otherwise every
request would result in another failed gconfd being spawned.
*/
- gconf_log(GCL_ERR, _("No configuration sources in the source path, configuration won't be saved; edit %s%s"), GCONF_CONFDIR, "/path");
+ gconf_log(GCL_ERR, _("No configuration sources in the source path. Configuration won't be saved; edit %s%s"), GCONF_CONFDIR, "/path");
/* don't request error since there aren't any addresses */
sources = gconf_sources_new_from_addresses(NULL, NULL);
@@ -372,7 +372,7 @@
if (error != NULL)
{
- gconf_log(GCL_ERR, _("Error loading some config sources: %s"),
+ gconf_log(GCL_ERR, _("Error loading some configuration sources: %s"),
error->message);
g_error_free(error);
@@ -384,7 +384,7 @@
g_assert(sources != NULL);
if (sources->sources == NULL)
- gconf_log(GCL_ERR, _("No config source addresses successfully resolved, can't load or store config data"));
+ gconf_log(GCL_ERR, _("No configuration source addresses successfully resolved. Can't load or store configuration data"));
tmp = sources->sources;
@@ -401,7 +401,7 @@
/* In this case, some sources may still return TRUE from their writable() function */
if (!have_writable)
- gconf_log(GCL_WARNING, _("No writable config sources successfully resolved, may not be able to save some configuration changes"));
+ gconf_log(GCL_WARNING, _("No writable configuration sources successfully resolved. May be unable to save some configuration changes"));
/* Install the sources as the default database */
@@ -1344,7 +1344,7 @@
ConfigException* ce;
ce = ConfigException__alloc();
- ce->message = CORBA_string_dup("config server is currently shutting down");
+ ce->message = CORBA_string_dup("Configuration server is currently shutting down");
ce->err_no = ConfigInShutdown;
CORBA_exception_set(ev, CORBA_USER_EXCEPTION,
@@ -1709,7 +1709,7 @@
if (err != NULL)
{
gconf_log (GCL_DEBUG,
- "Failed to unquote config source address from saved state file: %s",
+ "Failed to unquote configuration source address from saved state file: %s",
err->message);
g_error_free (err);
Modified: trunk/gconf/gconftool.c
==============================================================================
--- trunk/gconf/gconftool.c (original)
+++ trunk/gconf/gconftool.c Tue Jan 8 14:31:11 2008
@@ -262,7 +262,7 @@
0,
G_OPTION_ARG_NONE,
&spawn_gconfd,
- N_("Launch the config server (gconfd). (Normally happens automatically when needed.)"),
+ N_("Launch the configuration server (gconfd). (Normally happens automatically when needed.)"),
NULL
},
{
@@ -364,7 +364,7 @@
0,
G_OPTION_ARG_NONE,
&use_local_source,
- N_("Access the config database directly, bypassing server. Requires that gconfd is not running."),
+ N_("Bypass server, and access the configuration database directly. Requires that gconfd is not running."),
NULL
},
{
@@ -373,7 +373,7 @@
0,
G_OPTION_ARG_NONE,
&makefile_install_mode,
- N_("Properly installs schema files on the command line into the database. GCONF_CONFIG_SOURCE environment variable should be set to a non-default config source or set to the empty string to use the default."),
+ N_("Properly installs schema files on the command line into the database. Specify a custom configuration source in the GCONF_CONFIG_SOURCE environment variable, or set set the variable to an empty string to use the default configuration source."),
NULL
},
{
@@ -382,7 +382,7 @@
0,
G_OPTION_ARG_NONE,
&makefile_uninstall_mode,
- N_("Properly uninstalls schema files on the command line from the database. GCONF_CONFIG_SOURCE environment variable should be set to a non-default config source or set to the empty string to use the default."),
+ N_("Properly uninstalls schema files on the command line from the database. GCONF_CONFIG_SOURCE environment variable should be set to a non-default configuration source or set to the empty string to use the default."),
NULL
},
{
@@ -819,7 +819,7 @@
if (use_local_source && config_source == NULL)
{
- g_printerr (_("You must specify a config source with --config-source when using --direct\n"));
+ g_printerr (_("You must specify a configuration source with --config-source when using --direct\n"));
return 1;
}
@@ -1755,7 +1755,7 @@
if (!gconf_spawn_daemon(&err))
{
- g_printerr (_("Failed to spawn the config server (gconfd): %s\n"),
+ g_printerr (_("Failed to spawn the configuration server (gconfd): %s\n"),
err->message);
g_error_free(err);
err = NULL;
@@ -3885,7 +3885,7 @@
if (err != NULL)
{
- g_printerr (_("Error syncing config data: %s"),
+ g_printerr (_("Error syncing configuration data: %s"),
err->message);
g_error_free(err);
return 1;
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
--- trunk/gconf/gconf.c (original)
+++ trunk/gconf/gconf.c Tue Jan 8 14:31:11 2008
@@ -710,7 +710,7 @@
/* Don't set error because realistically this
doesn't matter to clients */
#ifdef GCONF_ENABLE_DEBUG
- g_warning("Failure removing listener %u from the config server: %s",
+ g_warning("Failure removing listener %u from the configuration server: %s",
(guint)gcnxn->server_id,
err->message);
#endif
@@ -2321,7 +2321,7 @@
* gconf_debug_shutdown:
* @void:
*
* Detach from the config server and release
* all related resources.
*
* Returns: 1 if an exception occurs, 0 otherwise.
@@ -3059,7 +3059,7 @@
if (ev._major != CORBA_NO_EXCEPTION)
{
if (err)
- *err = gconf_error_new (GCONF_ERROR_FAILED, _("Failure shutting down config server: %s"),
+ *err = gconf_error_new (GCONF_ERROR_FAILED, _("Failure shutting down configuration server: %s"),
CORBA_exception_id (&ev));
CORBA_exception_free(&ev);
Modified: trunk/gconf/gconfd.c
@@ -2321,7 +2321,7 @@
* @void:
*
- * Detach from the config server and release
+ * Detach from the configuration server and release
* all related resources.
*
==============================================================================